<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>AppearanceWidget</name>
    <message>
        <location filename="../PAppearanceWidget.ui" line="14"/>
        <source>Appearance</source>
        <translation>모양</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="25"/>
        <source>PageEdit</source>
        <translation>페이지 에디터</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="31"/>
        <location filename="../PAppearanceWidget.ui" line="263"/>
        <source>Fonts:</source>
        <translation>글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="40"/>
        <source>If no font is specified in the CSS for your page, the following font will be used to display within PageEdit. These fonts will not be used in your actual ebook.</source>
        <translation>CSS에 글꼴이 지정되지 않은 경우 다음 글꼴을 사용하여 PageEdit 내에 표시합니다. 이 글꼴은 실제 전자 책에서 사용되지 않습니다.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="70"/>
        <source>Default font size to be used for PageEdit
if no font-size specified in your CSS</source>
        <translation>CSS에서 글꼴 크기를 지정하지 않을 경우 페이지 에디터에서 사용할 기본 글꼴 크기</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="74"/>
        <location filename="../PAppearanceWidget.ui" line="323"/>
        <source>Font Size:</source>
        <translation>글자 크기:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="81"/>
        <source>Default font family to be used for PageEdit
if no font-family specified in your CSS</source>
        <translation>CSS에서 글꼴 모음을 지정하지 않을 경우 페이지 에디터에서 사용할 기본 글꼴 모음</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="85"/>
        <source>Standard:</source>
        <translation>기본 글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="108"/>
        <source>Default font family to be used for PageEdit
if a serif font-family specified in your CSS</source>
        <translation>CSS에서 명조 계열 글꼴(serif)을 지정한 경우 페이지 에디터에서 사용할 기본 글꼴 모음</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="112"/>
        <source>Serif:</source>
        <translation>명조 계열 글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="125"/>
        <source>Default font family to be used for PageEdit
if a sans-serif font-family specified in your CSS</source>
        <translation>CSS에서 고딕 계열 글꼴(sans-serif)을 지정한 경우 페이지 에디터에서 사용할 기본 글꼴 모음</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="129"/>
        <source>Sans-Serif:</source>
        <translation>고딕 계열 글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="156"/>
        <source>Make PageEdit simulate a dark appearance in dark mode</source>
        <translation>다크 모드에서 페이지 에디터를 다크 모드로 변경</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="181"/>
        <source>Main UI</source>
        <translation>기본 UI</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="187"/>
        <source>Main Menu Icon Size:</source>
        <translation>기본 메뉴 아이콘 크기: </translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="193"/>
        <source>Adjust the size of the icons in the main menu.</source>
        <translation>메인 메뉴 아이콘 크기 조절</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="231"/>
        <source>High DPI Setting:</source>
        <translation>High DPI 설정:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="240"/>
        <source>(Needs PageEdit Restart)</source>
        <translation>(페이지 에디터를 다시 시작해야 합니다)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="269"/>
        <source>UI Font:</source>
        <translation>UI 글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="279"/>
        <source>Change the font used by PageEdit&apos;s menus, buttons, etc...</source>
        <translation>페이지 에디터의 메뉴, 버튼 등에 사용되는 글꼴 변경</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="282"/>
        <source>Change Font (Needs PageEdit Restart)</source>
        <translation>글꼴 변경(페이지 에디터를 다시 시작해야 합니다)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="306"/>
        <source>Insert Special Characters:</source>
        <translation>특수 문자 삽입 :</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="320"/>
        <source>Font size to be used for Insert Special Characters window</source>
        <translation>특수 문자 삽입 창에서 사용할 글자 크기</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="353"/>
        <source>Font family to be used for Insert Special Characters window</source>
        <translation>특수 문자 삽입 창에서 사용할 글꼴 모음</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="356"/>
        <source>Standard Font:</source>
        <translation>기본 글꼴:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="423"/>
        <source>Reset all fonts and colors to the default values</source>
        <translation>모든 글꼴과 색상을 기본값으로 초기화합니다</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="426"/>
        <source>Reset All</source>
        <translation>모두 초기화</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect</source>
        <translation>감지</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>On</source>
        <translation>켜기</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Off</source>
        <translation>끄기</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect whether any high dpi scaling should take place.</source>
        <translation>High dpi 스케일링이 발생하는지 감지합니다.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="51"/>
        <source>Defers to any Qt environment variables that are set to control high dpi behavior.</source>
        <translation>High dpi 동작을 제어하도록 설정된 Qt 환경 변수를 연기합니다.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>Turns on high dpi scaling and ignores any Qt environment variables</source>
        <translation>High dpi 스케일링을 켜고 Qt 환경 변수를 무시합니다.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="53"/>
        <source>that are set controlling high dpi behavior.</source>
        <translation>High dpi 동작을 제어하도록 설정되어 있습니다.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Turns off high dpi scaling regardless if any Qt environment</source>
        <translation>Qt 환경에 관계없이 High dpi 스케일링을 끕니다.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="55"/>
        <source>variables controlling high dpi behavior are set.</source>
        <translation>High dpi 동작을 제어하는 ​​변수가 설정됩니다.</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../PGeneralSettings.ui" line="14"/>
        <source>General Settings</source>
        <translation>일반 설정</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="37"/>
        <source>You must restart PageEdit after changing the User Interface language.

If a translation for specific word or phrase is not available it will be displayed in English.</source>
        <translation>사용자 인터페이스 언어를 변경 한 후에는 반드시 PageEdit를 다시 시작해야합니다.  번역되지 않은 특정 단어나 구문은 영어로 표시됩니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="42"/>
        <source>User Interface Language:</source>
        <translation>사용자 인터페이스 언어:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="74"/>
        <source>Select from installed spellcheck dictionaries.</source>
        <translation>설치된 맞춤법 검사 사전에서 선택</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="77"/>
        <source>Spellcheck Dictionary:</source>
        <translation>맞춤법 검사 사전</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="119"/>
        <source>Determine if html files are allowed to access non-multimedia remote resources.</source>
        <translation>멀티미디어 이외의 원격 리소스를 HTML 파일에 사용할 수 있는지 설정합니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="122"/>
        <source> Control access by html files to non-multimedia remote resources.</source>
        <translation>멀티미디어 이외의 원격 리소스를 HTML 파일에 사용할 수 있도록 설정</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="131"/>
        <source>Check to allow html files to access non-multimedia remote resources.</source>
        <translation>체크를 하면 모든 형태의 원격 리소스를 HTML 파일에 사용할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="134"/>
        <source>Html files may access all remote resources types.</source>
        <translation>HTML 파일에서 모든 형태의 원격 리소스 허용</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="161"/>
        <source>Determine if javascript is allowed to be used by html files</source>
        <translation>HTML 파일에서 자바 스크립트를 사용할 수 있는지 설정할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="164"/>
        <source> Control use of javascript by html files.</source>
        <translation>HTML 파일에서 자바 스크립트 사용 설정</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="173"/>
        <source>Check to allow html files to use javascript.</source>
        <translation>체크를 하면 HTML 파일에서 자바스크립트를 사용할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="176"/>
        <source>Html files may use javascript.</source>
        <translation>HTML에서 자바스크립트 허용</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="204"/>
        <source>Choose how you would like PageEdit to handle the use of multiple white space characters during editing.</source>
        <translation>페이지 에디터에서 코드보기 상에서 연속으로 입력된 2개 이상의 공백 글자를 어떻게 표현할지 결정합니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="207"/>
        <source>Handle multiple white space layout using:</source>
        <translation>연속된 공백 표시 방식 선택</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="213"/>
        <source>Use CSS white-space: pre-wrap</source>
        <translation>CSS white-space: pre-wrap(공백 보존) 방식을 사용합니다. 공백 만큼 간격이 벌어지기 때문에 실제 전자책과 다르게 보일 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="216"/>
        <source>css white-space: pre-wrap</source>
        <translation>공백을 그대로 표시(css white-space: pre-wrap)</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="226"/>
        <source>Use non-breaking spaces as needed</source>
        <translation>공백을 하나만 표시하고 나머지는 무시합니다. 대부분의 전자책 뷰어에서 동일하게 보입니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="229"/>
        <source>non-breaking spaces as needed</source>
        <translation>공백 무시(non-breaking spaces and needed)</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="257"/>
        <source>Determine if Prettify is used when saving</source>
        <translation>저장시 태그 정리(Prettify) 사용할 것인지 선택합니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="260"/>
        <source> Use Prettify to reformat the xhtml when saving.</source>
        <translation>xhtml 저장 시 코드 정리(Prettify) 사용</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="269"/>
        <source>Check to reformat with Prettify when saving xhtml files.</source>
        <translation>체크를 하면 xhtml을 저장할 때 Prettify 방식으로 태그를 정리합니다.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="272"/>
        <source>Use Prettify to reformat xhtml when saving.</source>
        <translation>xhtml 저장시 코드 정리(Prettify) 사용</translation>
    </message>
</context>
<context>
    <name>Inspector</name>
    <message>
        <location filename="../Inspector.cpp" line="74"/>
        <source>Inspect Page or Element</source>
        <translation>페이지 또는 요소 검사</translation>
    </message>
    <message>
        <location filename="../Inspector.cpp" line="156"/>
        <source>The Inspector functionality is not supported before Qt 5.11</source>
        <translation>검사 기능은 Qt 5.11 이전에는 지원되지 않습니다.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="15"/>
        <location filename="../MainWindow.cpp" line="1012"/>
        <location filename="../MainWindow.cpp" line="1073"/>
        <location filename="../MainWindow.cpp" line="1764"/>
        <location filename="../MainWindow.cpp" line="1777"/>
        <location filename="../MainWindow.cpp" line="1783"/>
        <location filename="../MainWindow.cpp" line="1797"/>
        <location filename="../MainWindow.cpp" line="1810"/>
        <location filename="../MainWindow.cpp" line="1818"/>
        <location filename="../MainWindow.cpp" line="1873"/>
        <location filename="../MainWindow.cpp" line="1960"/>
        <source>PageEdit</source>
        <translation>페이지 에디터</translation>
    </message>
    <message>
        <location filename="../main.ui" line="62"/>
        <source>&amp;File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="75"/>
        <source>&amp;Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <location filename="../main.ui" line="88"/>
        <source>&amp;Find</source>
        <translation>&amp;찾기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="95"/>
        <source>&amp;Insert</source>
        <translation>삽입(&amp;I)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="110"/>
        <source>For&amp;mat</source>
        <translation>서식(&amp;m)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="115"/>
        <source>&amp;Heading</source>
        <translation>제목 스타일(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="130"/>
        <source>C&amp;hange Case</source>
        <translation>대/소문자 변경(&amp;H)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="160"/>
        <source>&amp;View</source>
        <translation>보기(&amp;V)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="169"/>
        <source>Inspector</source>
        <translation>검사</translation>
    </message>
    <message>
        <location filename="../main.ui" line="185"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="199"/>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <location filename="../main.ui" line="217"/>
        <location filename="../main.ui" line="1157"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../main.ui" line="230"/>
        <source>Insert</source>
        <translation>삽입</translation>
    </message>
    <message>
        <location filename="../main.ui" line="249"/>
        <source>Inspect</source>
        <translation>검사</translation>
    </message>
    <message>
        <location filename="../main.ui" line="262"/>
        <location filename="../main.ui" line="1106"/>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="275"/>
        <source>Heading</source>
        <translation>제목 스타일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="289"/>
        <source>set Heading Level of Selected Text</source>
        <translation>선택한 텍스트의 제목 수준 설정</translation>
    </message>
    <message>
        <location filename="../main.ui" line="303"/>
        <source>Change Case</source>
        <translation>대소문자 변경</translation>
    </message>
    <message>
        <location filename="../main.ui" line="319"/>
        <source>Format</source>
        <translation>서식</translation>
    </message>
    <message>
        <location filename="../main.ui" line="337"/>
        <source>Align</source>
        <translation>정렬</translation>
    </message>
    <message>
        <location filename="../main.ui" line="353"/>
        <source>Indent</source>
        <translation>들여쓰기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="367"/>
        <source>Navigate</source>
        <translation>목차</translation>
    </message>
    <message>
        <location filename="../main.ui" line="377"/>
        <source>Navigation List</source>
        <translation>목차 목록</translation>
    </message>
    <message>
        <location filename="../main.ui" line="393"/>
        <source>&amp;Save</source>
        <translation>저장(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="396"/>
        <source>Save the current file.</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <location filename="../main.ui" line="399"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="409"/>
        <source>&amp;Print</source>
        <translation>&amp;인쇄</translation>
    </message>
    <message>
        <location filename="../main.ui" line="412"/>
        <source>Print the current Page.</source>
        <translation>현재 페이지 인쇄</translation>
    </message>
    <message>
        <location filename="../main.ui" line="415"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../main.ui" line="421"/>
        <source>Save &amp;As...</source>
        <translation>다른 이름으로 저장하기(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="424"/>
        <source>Save the current file with a different filename.</source>
        <translation>다른 이름으로 저장</translation>
    </message>
    <message>
        <location filename="../main.ui" line="427"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="437"/>
        <source>Cu&amp;t</source>
        <translation>잘라내기(&amp;t)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="440"/>
        <source>Cuts the selected text from the document and puts it on the clipboard.</source>
        <translation>선택한 텍스트를 문서에서 잘라내어 클립 보드에 저장합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="450"/>
        <source>&amp;Paste</source>
        <translation>붙여넣기(&amp;P)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="453"/>
        <source>Pastes the content from the clipboard into the file.</source>
        <translation>클립 보드의 내용을 파일에 붙여 넣습니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="463"/>
        <source>&amp;Undo</source>
        <translation>되돌리기(&amp;U)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="466"/>
        <source>Reverts the changes of the previous operation.</source>
        <translation>이전에 작업한 변경 사항을 되돌립니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="469"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../main.ui" line="479"/>
        <source>&amp;Redo</source>
        <translation>다시 실행(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="482"/>
        <source>Restores the changes reverted by the previous Undo action.</source>
        <translation>실행 취소로 되돌려 진 이전 변경 내용을 복원합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="485"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../main.ui" line="495"/>
        <source>&amp;Copy</source>
        <translation>복사(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Copies the selected text and puts it on the clipboard.</source>
        <translation>선택한 텍스트를 복사하여 클립 보드에 저장합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="511"/>
        <source>Align &amp;Left</source>
        <translation>왼쪽 정렬(&amp;L)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="514"/>
        <source>Align the paragraph to the left.</source>
        <translation>단락에 왼쪽 정렬 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="528"/>
        <source>Align &amp;Right</source>
        <translation>오른쪽 정렬(&amp;R)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="531"/>
        <source>Align the paragraph to the right.</source>
        <translation>단락에 오른쪽 정렬 스타일을 적용합니다. </translation>
    </message>
    <message>
        <location filename="../main.ui" line="544"/>
        <source>&amp;Center</source>
        <translation>가운데 정렬(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="547"/>
        <source>Center the paragraph.</source>
        <translation>단락에 가운데 정렬 스타일을 적요합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="550"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../main.ui" line="563"/>
        <source>&amp;Justify</source>
        <translation>양쪽 맞춤(&amp;J)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="566"/>
        <source>Align the paragraph to both the left and right margins.</source>
        <translation>단락에 양쪽 정렬 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="569"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../main.ui" line="582"/>
        <source>&amp;Bold</source>
        <translation>진하게</translation>
    </message>
    <message>
        <location filename="../main.ui" line="585"/>
        <source>Make the selected text bold.</source>
        <translation>선택한 텍스트에 진하게 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="588"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main.ui" line="601"/>
        <source>&amp;Italic</source>
        <translation>기울임꼴</translation>
    </message>
    <message>
        <location filename="../main.ui" line="604"/>
        <source>Make the selected text italic.</source>
        <translation>선택한 텍스에 이탤릭체 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="607"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main.ui" line="617"/>
        <source>&amp;Open...</source>
        <translation>열기...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="620"/>
        <source>Open a file from disk.</source>
        <translation>저장된 파일을 엽니 다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="623"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../main.ui" line="636"/>
        <source>&amp;Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <location filename="../main.ui" line="639"/>
        <source>Underline the selected text.</source>
        <translation>선택한 텍스트에 밑줄 스타일을 적용합니다. </translation>
    </message>
    <message>
        <location filename="../main.ui" line="642"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="652"/>
        <source>&amp;Lowercase</source>
        <translation>소문자로(&amp;L)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="655"/>
        <source>Set selected text to lowercase.</source>
        <translation>선택한 텍스트를 소문자로 설정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="658"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="668"/>
        <source>&amp;Uppercase</source>
        <translation>대문자로(&amp;U)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="671"/>
        <source>Set selected text to uppercase.</source>
        <translation>선택한 텍스트를 대문자로 설정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="674"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="684"/>
        <source>&amp;Titlecase</source>
        <translation>제목 스타일 대소문자(&amp;T)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="687"/>
        <source>Capitalize the first letter of each word selected.</source>
        <translation>선택한 각 단어의 첫 글자를 대문자로 표시합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Capitalize</source>
        <translation>&amp;첫 글자를 대문자로</translation>
    </message>
    <message>
        <location filename="../main.ui" line="700"/>
        <source>Capitalize only the first word of the selected text.</source>
        <translation>선택한 텍스트의 첫 번째 단어 만 대문자로 표시합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="710"/>
        <source>&amp;Quit</source>
        <translation>나가기(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="713"/>
        <source>Quit</source>
        <translation>나가기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main.ui" line="726"/>
        <source>&amp;Special Character...</source>
        <translation>특수 문자(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="729"/>
        <source>Select a character to insert into your text.</source>
        <translation>텍스트에 삽입 할 문자를 선택하십시오.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="742"/>
        <source>&amp;Numbered List</source>
        <translation>번호 매기기 목록</translation>
    </message>
    <message>
        <location filename="../main.ui" line="745"/>
        <source>Create a numbered list from selection.</source>
        <translation>선택 항목을 번호 매기기 목록으로 만듭니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="758"/>
        <source>Bulle&amp;ted List</source>
        <translation>글머리 기호 목록</translation>
    </message>
    <message>
        <location filename="../main.ui" line="761"/>
        <source>Create a bulleted list from selection.</source>
        <translation>선택 항목을 글머리 기호 목록으로 만듭니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="764"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="777"/>
        <source>Stri&amp;kethrough</source>
        <translation>취소선(&amp;K)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="780"/>
        <source>Draw a line through the selected text.</source>
        <translation>선택한 텍스트에 취소선 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="793"/>
        <source>&amp;Subscript</source>
        <translation>아래 첨자(&amp;S)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="796"/>
        <source>Set the selected text slightly smaller and below the normal line.</source>
        <translation>선택한 텍스트에 아래첨자 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="809"/>
        <source>Su&amp;perscript</source>
        <translation>위첨자</translation>
    </message>
    <message>
        <location filename="../main.ui" line="812"/>
        <source>Set the selected text slightly smaller and above the normal line.</source>
        <translation>선택한 텍스트에 위첨자 스타일을 적용합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="823"/>
        <source>Zoom &amp;In</source>
        <translation>확대</translation>
    </message>
    <message>
        <location filename="../main.ui" line="826"/>
        <source>Zoom In</source>
        <translation>확대</translation>
    </message>
    <message>
        <location filename="../main.ui" line="829"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../main.ui" line="840"/>
        <source>Zoom &amp;Out</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../main.ui" line="843"/>
        <source>Zoom Out</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../main.ui" line="846"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../main.ui" line="857"/>
        <source>Incre&amp;ase Indent</source>
        <translation>들여쓰기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="860"/>
        <source>Increase the indent level of the paragraph.</source>
        <translation>문단의 들여쓰기 수준을 증가시킵니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="863"/>
        <source>Ctrl+Alt+M</source>
        <translation>Ctrl+Alt+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="873"/>
        <source>&amp;Decrease Indent</source>
        <translation>둘여쓰기 취소</translation>
    </message>
    <message>
        <location filename="../main.ui" line="876"/>
        <source>Decrease the indent level of the paragraph.</source>
        <translation>문단의 들여쓰기 수준을 감소시킵니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="879"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="889"/>
        <source>Split &amp;Marker</source>
        <translation>나눌 위치 표시</translation>
    </message>
    <message>
        <location filename="../main.ui" line="892"/>
        <source>Insert Sigil split file marker</source>
        <translation>파일을 나눌 위치를 표시합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="895"/>
        <source>Ctrl+Shift+Return</source>
        <translation>Ctrl+Shift+Return</translation>
    </message>
    <message>
        <location filename="../main.ui" line="901"/>
        <source>&amp;Preferences...</source>
        <translation>설정(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="904"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="910"/>
        <source>&amp;Zoom Reset</source>
        <translation>줌 리셋(&amp;Z)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="913"/>
        <source>Zoom Reset</source>
        <translation>확대/축소 다시 설정</translation>
    </message>
    <message>
        <location filename="../main.ui" line="916"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../main.ui" line="929"/>
        <source>Heading &amp;1</source>
        <translation>Heading &amp;1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="932"/>
        <source>Format paragraph as a level 1 heading.</source>
        <translation>h1 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="935"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="948"/>
        <source>Heading &amp;2</source>
        <translation>Heading &amp;2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="951"/>
        <source>Format paragraph as a level 2 heading.</source>
        <translation>h2 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="954"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="967"/>
        <source>Heading &amp;3</source>
        <translation>Heading &amp;3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="970"/>
        <source>Format paragraph as a level 3 heading.</source>
        <translation>h3 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="973"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="987"/>
        <source>Heading &amp;4</source>
        <translation>Heading &amp;4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="990"/>
        <source>Format paragraph as a level 4 heading.</source>
        <translation>h4 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="993"/>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1006"/>
        <source>Heading &amp;5</source>
        <translation>Heading &amp;5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1009"/>
        <source>Format paragraph as a level 5 heading.</source>
        <translation>h5 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1012"/>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1025"/>
        <source>Heading &amp;6</source>
        <translation>Heading &amp;6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1028"/>
        <source>Format paragraph as a level 6 heading.</source>
        <translation>h6 제목으로 단락 서식을 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1031"/>
        <source>Ctrl+6</source>
        <translation>Ctrl+6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1045"/>
        <source>&amp;Normal</source>
        <translation>&amp;기본문단</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1048"/>
        <source>ormat paragraph as a normal paragraph.</source>
        <translation>기본 문단(p)으로 지정합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1051"/>
        <source>Ctrl+7</source>
        <translation>Ctrl+7</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1061"/>
        <source>&amp;Preserve Existing Attributes</source>
        <translation>&amp;기존 속성 유지</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1064"/>
        <source>When applying this style, preserve any existing attributes on the tag</source>
        <translation>이 스타일을 적용할때 태그에 있는 기존의 특성(attributes)은 보존됩니다</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1074"/>
        <source>&amp;Select All</source>
        <translation>&amp;모두 선택</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1077"/>
        <source>Select all text in the document.</source>
        <translation>문서 내의 모든 텍스트를 선택합니다.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1080"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1090"/>
        <source>&amp;Inspector</source>
        <translation>코드 검사기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1093"/>
        <source>Inspect the page.</source>
        <translation>페이지 검사</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1096"/>
        <source>Ctrl+F5</source>
        <translation>Ctrl+F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1109"/>
        <source>Find text in the page</source>
        <translation>페이지 안에서 찾기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1112"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1125"/>
        <source>Next XHtml File</source>
        <translation>다음 XHtml 파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1128"/>
        <source>Next file in navigation list</source>
        <translation>목차 목록의 다음 파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1141"/>
        <source>Previous XHtml File</source>
        <translation>이전 XHtml 파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1144"/>
        <source>Previous file in navigation list</source>
        <translation>목차 목록의 이전 파일</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1160"/>
        <source>Toggle between Edit and Preview Modes.</source>
        <translation>편집, 미리보기 모드 전환</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1170"/>
        <source>About...</source>
        <translation>페이지 에디터 정보</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1173"/>
        <source>Show information about PageEdit.</source>
        <translation>페이지 에디터 정보 보기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1183"/>
        <source>Back to Last Link</source>
        <translation>마지막 링크로 돌아가기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1186"/>
        <source>Return from the last link taken</source>
        <translation>마지막으로 연결한 링크에서 돌아오기</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1196"/>
        <source>I&amp;D...</source>
        <translation>I&amp;D...
</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1199"/>
        <source>Insert or edit an anchor with an ID name to use as a link target.</source>
        <translation>링크 타겟용 ID 이름으로 사용할 앵커를 삽입하거나 편집하십시오.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1209"/>
        <source>&amp;Link...</source>
        <translation>&amp;링크....</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1212"/>
        <source>Insert or edit an anchor with a hyperlink to a target.</source>
        <translation>하이퍼 링크 타겟용 ID 이름으로 사용할 앵커를 삽입하거나 편집하십시오.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1222"/>
        <source>&amp;File...</source>
        <translation>&amp;파일....</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1225"/>
        <source>Select existing image, video or audio files from your book to insert into the text.</source>
        <translation>책에서 기존 이미지, 비디오 또는 오디오 파일을 선택하여 텍스트에 삽입하십시오.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1228"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="750"/>
        <source>File load failed</source>
        <translation>파일을 불러오지 못했습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="751"/>
        <source>File Load Failed</source>
        <translation>파일을 불러오지 못했습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="846"/>
        <source>mode: Preview</source>
        <translation>mode: 미리보기</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="848"/>
        <source>mode: Edit</source>
        <translation>mode: 편집</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1012"/>
        <source>Are you sure you want to open this link in your browser?

%1</source>
        <translation>브라우저에서 이 링크를 열겠습니까?

%1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1074"/>
        <source>Do you want to save your changes before leaving?</source>
        <translation>종료하기 전에 변경 사항을 저장하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1091"/>
        <source>PageEdit is closing...</source>
        <translation>페이지 에디터를 종료합니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1223"/>
        <location filename="../MainWindow.cpp" line="1224"/>
        <location filename="../MainWindow.cpp" line="1225"/>
        <location filename="../MainWindow.cpp" line="1234"/>
        <location filename="../MainWindow.cpp" line="1235"/>
        <location filename="../MainWindow.cpp" line="1236"/>
        <source>HTML files (*.htm *.html *.xhtml)</source>
        <translation>HTML 파일 (*.htm *.html *.xhtml)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1226"/>
        <source>OPF files (*.opf)</source>
        <translation>OPF 파일 (*.opf)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1227"/>
        <source>All files (*.*)</source>
        <translation>모든 파일 (*.*)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1466"/>
        <source>Save File</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <location filename="../MainWindow.cpp" line="1502"/>
        <location filename="../MainWindow.cpp" line="1514"/>
        <location filename="../MainWindow.cpp" line="1515"/>
        <source>File Save-As Failed!</source>
        <translation>다른이름으로 파일 저장 실패!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <source>is not writeable</source>
        <translation>저장할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1510"/>
        <location filename="../MainWindow.cpp" line="1549"/>
        <source>File Saved</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1540"/>
        <location filename="../MainWindow.cpp" line="1542"/>
        <location filename="../MainWindow.cpp" line="1553"/>
        <location filename="../MainWindow.cpp" line="1554"/>
        <source>File Save Failed!</source>
        <translation>파일 저장 실패</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1541"/>
        <source>does not exist or is not writeable</source>
        <translation>존재하지 않거나 저장할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1570"/>
        <source>Do not show this warning again</source>
        <translation>이 경고를 다시 표시하지 않음</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1571"/>
        <source>This file may not print the way you expect it to.</source>
        <translation>이 파일은 예상대로 인쇄되지 않을 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1572"/>
        <source>Dark backgrounds and colored text applied with an EPUB&apos;s CSS will print.</source>
        <translation>EPUB의 CSS로 적용된 어두운 배경과 컬러 텍스트가 인쇄됩니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1573"/>
        <source>Use caution as this can result in a lot of ink being used!</source>
        <translation>잉크를 많이 사용할 수 있으므로주의하십시오!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1574"/>
        <source>Use the following Print Preview to see how this file will print.</source>
        <translation>인쇄 미리보기를 사용하여이 파일이 어떻게 인쇄되는지 확인합니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1575"/>
        <source>Check the box if you don&apos;t wish to see this warning in the future.</source>
        <translation>앞으로 이 경고를 보지 않으려면 체크 박스를 선택하세요.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1598"/>
        <source>Feature not available before Qt5.12.x</source>
        <translation>Qt5.12.x 이전에는 사용할 수 없었던 기능</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1660"/>
        <source>File Opened</source>
        <translation>파일을 열었습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1664"/>
        <source>File Open Failed!</source>
        <translation>파일을 열지 못했습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1687"/>
        <source>Clipboard contains HTML formatting</source>
        <translation>클립보드에 HTML 서식이 있습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1688"/>
        <source>Do you want to paste clipboard data as plain text?</source>
        <translation>클립보드의 내용을 서식 없는 텍스트로 추가하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1764"/>
        <source>You must select text before inserting a new id.</source>
        <translation>새 ID를 삽입할 텍스트를 먼저 선택하세요. </translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1777"/>
        <source>ID is invalid - must start with a letter, followed by letter number _ : - or .</source>
        <translation>잘못된 ID - 반드시 영문으로 시작하고 영문, 숫자, 언더바(_) 콜론(:), 하이픈(-) 혹은 점(.)만 사용 가능</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1783"/>
        <source>You cannot insert an id at this position.</source>
        <translation>이 위치에는 ID를 삽입할 수 없습니다. </translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1797"/>
        <source>You must select text before inserting a new link.</source>
        <translation>링크를 삽입할 텍스트를 먼저 선택하세요.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1810"/>
        <source>Link is invalid - cannot contain &apos;&lt;&apos; or &apos;&gt;&apos;</source>
        <translation>잘못된 링크 - &apos;&lt;&apos;나 &apos;&gt;&apos;는 포함할 수 없음</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1818"/>
        <source>You cannot insert a link at this position.</source>
        <translation>이 위치에는 링크를 삽입할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1829"/>
        <source>Insert File</source>
        <translation>파일 삽입</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1873"/>
        <source>You cannot insert a media file at this position.</source>
        <translation>이 위치에는 미디어 파일을 삽입할 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1961"/>
        <source>Do you want to save any changes before overwriting this file?</source>
        <translation>이 파일을 덮어쓰기 전에 모든 변경사항을 저장하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../Preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>PageEdit</source>
        <translation>페이지 에디터</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>Changes will take effect when you restart PageEdit.</source>
        <translation>페이지 에디터를 다시 시작하면 변경사항이 반영됩니다.</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="152"/>
        <source>Open Preferences Location</source>
        <translation>기본 설정 위치 열기</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../OPFReader.cpp" line="59"/>
        <source>Unable to read OPF file.
Line: %1 Column %2 - %3</source>
        <translation>OPF 파일을 읽을 수 없습니다.
Line: %1 Column %2 - %3</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="379"/>
        <source>Cannot read file %1:
%2.</source>
        <translation>다음 파일을 읽을 수 없습니다 %1:
%2.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="560"/>
        <source>PageEdit has encountered a problem.</source>
        <translation>페이지 에디터에 문제가 생겼습니다.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="561"/>
        <source>PageEdit may need to close.</source>
        <translation>페이지 에디터를 종료해야 합니다.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="863"/>
        <source>About PageEdit</source>
        <translation>페이지 에디터 정보</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="868"/>
        <source>Version</source>
        <translation>버전</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="869"/>
        <source>Build Date</source>
        <translation>배포일</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="870"/>
        <source>Build Time</source>
        <translation>배포 시간</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="871"/>
        <source>Qt Runtime Version</source>
        <translation>Qt Runtime 버전</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="872"/>
        <source>Qt Compiled Version</source>
        <translation>Qt Compiled 버전</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="873"/>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="874"/>
        <source>Architecture</source>
        <translation>Architecture</translation>
    </message>
</context>
<context>
    <name>SearchToolbar</name>
    <message>
        <location filename="../SearchToolbar.ui" line="36"/>
        <source>Search: </source>
        <translation>검색:</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="55"/>
        <source>Search...</source>
        <translation>검색...</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="88"/>
        <source>&amp;Match Case</source>
        <translation>&amp;일치 여부</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.cpp" line="137"/>
        <source>No results found.</source>
        <translation>검색 결과 없음</translation>
    </message>
</context>
<context>
    <name>SelectCharacter</name>
    <message>
        <location filename="../SelectCharacter.ui" line="14"/>
        <source>Insert Special Character</source>
        <translation>특수 문자 삽입</translation>
    </message>
</context>
<context>
    <name>SelectFiles</name>
    <message>
        <location filename="../SelectFiles.ui" line="14"/>
        <source>Insert File</source>
        <translation>파일 삽입</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="46"/>
        <source>List only the file names which contain the text you enter.</source>
        <translation>입력한 텍스트가 포함된 파일만 보기.</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="49"/>
        <source>Filter:</source>
        <translation>필터:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="118"/>
        <source>Thumbnail size:</source>
        <translation>썸네일 크기:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="113"/>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="114"/>
        <source>Images</source>
        <translation>이미지</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="115"/>
        <source>Video</source>
        <translation>비디오</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="116"/>
        <source>Audio</source>
        <translation>오디오</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="159"/>
        <source>Media Files In the Book</source>
        <translation>책의 미디어 파일</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="162"/>
        <source>Thumbnails</source>
        <translation>썸네일</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>shades</source>
        <translation>그림자</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>colors</source>
        <translation>색상</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Grayscale</source>
        <translation>회색조(Grayscale)</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Color</source>
        <translation>색상</translation>
    </message>
</context>
<context>
    <name>SelectHyperlink</name>
    <message>
        <location filename="../SelectHyperlink.ui" line="14"/>
        <source>Select Target</source>
        <translation>대상 선택</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="22"/>
        <source>List only the entries that match the text you enter.</source>
        <translation>입력한 텍스트와 일치하는 항목만 보기.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="25"/>
        <source>Filter:</source>
        <translation>필터:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="58"/>
        <source>Enter the target URL for this hyperlink.  You can select or 
double click on existing destinations in your book from the list above.</source>
        <translation>링크를 걸 타겟 URL을 입력하세요. 위 목록에서 책의 기존 대상을 선택하거나 더블클릭으로 선택 할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="62"/>
        <source>Target:</source>
        <translation>대상 : </translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="94"/>
        <source>Targets in the Book</source>
        <translation>책 내의 링크 Target</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="95"/>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
</context>
<context>
    <name>SelectId</name>
    <message>
        <location filename="../SelectId.ui" line="14"/>
        <source>Insert ID </source>
        <translation>ID 삽입</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="22"/>
        <source>Enter an ID name to use as a destination for hyperlinks, notes, and TOC entries.

The dropdown box shows existing ID names in the current file.

ID names must be unique and start with a letter.</source>
        <translation>하이퍼 링크, 메모 및 목차 항목의 대상으로 사용할 ID 이름을 입력하십시오. 드롭 다운 상자는 현재 파일의 기존 ID 이름을 표시합니다 . ID 이름은 고유해야하며 영문으로 시작해야합니다.</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="29"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
</context>
<context>
    <name>Utility</name>
    <message>
        <location filename="../Utility.cpp" line="656"/>
        <source>PageEdit</source>
        <translation>페이지 에디터</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="657"/>
        <source>The requested file name contains non-ASCII characters. You should only use ASCII characters in filenames. Using non-ASCII characters can prevent the EPUB from working with some readers.

Continue using the requested filename?</source>
        <translation>요청한 파일 명에 non-ASCII 문자가 포함되어 있습니다. 파일명에는 ASCII 문자만 사용할 수 있습니다. non-ASCII 문자를 사용할 경우 일부 전자책 뷰어에서 작동하지 않을 수 있습니다.
그래도 파일명을 사용하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>WebViewEdit</name>
    <message>
        <location filename="../WebViewEdit.cpp" line="167"/>
        <source>No suggestions</source>
        <translation>추천이 없습니다.</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="179"/>
        <source>Check Spelling</source>
        <translation>맞춤법 검사</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="188"/>
        <source>Select Language</source>
        <translation>언어 선택</translation>
    </message>
</context>
</TS>